@@ -1,28 +1,40 @@
 #include "list.ih"
 
-void listCompare(LISTVAR_ *lhs, LISTVAR_ const *rhs)
+void listCompare(ListVariable *lhs, ListVariable const *rhs)
 {
     int ret = 0;
 
-    size_t idx;
-    size_t l_size = size(lhs);
+    unsigned idx;
+    unsigned size = l_size(lhs);
 
-    if (l_size != size(rhs))
+    if (size != l_size(rhs))
     {
         listDestructor(lhs);
-        *lhs = *intConstructor_i((int)(l_size - size(rhs)));
+        intcons_int(lhs, (int)(size - l_size(rhs)));
         return;
     }
 
-    for (idx = 0; idx < l_size; ++idx)
+    for (idx = 0; idx != size; ++idx)
     {
-        ret = strcmp(element(lhs)[idx], element(rhs)[idx]);
-        if (ret)
+        if (
+            (ret = strcmp(l_constElement(lhs)[idx], 
+                          l_constElement(rhs)[idx])) != 0
+        )
             break;
     }
+
+    listDestructor(lhs);
                                 /* Can't use the return value as-is, since  */
                                 /* the non-16 bit return value may have its */
                                 /* lower 16 bits set to zero (as happened   */
                                 /* on the powerpc                           */
-    *lhs = *intConstructor_i(ret < 0 ? -1 : ret > 0 ? 1 : 0);
+    intcons_int(lhs, ret < 0 ? -1 : ret > 0 ? 1 : 0);
 }
+
+
+
+
+
+
+
+
