@@ -22,7 +22,7 @@ void about(char const *program)
             "\n",
 
             "ICMAKE's home page is:\n"
-            "    http://fbb-git.github.io/icmake/\n"
+            "    http://fbb-git.gitlab.io/icmake/\n"
             "Also, ICMAKE is included in the Debian Linux distribution\n"
             "\n"
             "Questions, remarks, etc. about ICMAKE can be sent to:\n"
