@@ -1,75 +1,95 @@
-#include "icmun.h"
+#include "icmun.ih"
 
-BIN_HEADER_
-    *headerp;
+BinHeader *headerp;
 
 char
     *funname [] =
     {
+        /* 0 */
         "arghead",
         "argtail",
-        "ascii_str2int",
         "ascii_int2str",
+        "ascii_str2int",
 
+        /* 4 */
+        "backtick",
         "change_base",
-        "chdir",
         "change_ext",
-        "cmdhead",
-        "cmdtail",
         "change_path",
 
+        /* 8 */
+        "chdir",
+        "cmdhead",
+        "cmdtail",
         "echo",
+
+        /* c */
         "list_element",
+        "eval",
         "exec",
         "execute",
-        "exists",
 
-        "strtok",
+        /* 10 */
+        "exists",
         "fgets",
         "fprintf",
-
         "get_base",
-        "getch",
-        "gets",
+
+        /* 14 */
+        "get_dext",
         "get_ext",
         "get_path",
+        "getch",
 
+        /* 18 */
+        "getenv",
+        "getpid",
+        "gets",
+        "listlen",
+
+        /* 1c */
         "makelist",
-
         "printf",
         "putenv",
-
-        "sizeoflist",
         "stat",
+
+        /* 20 */
         "string_element",
-        "strlwr",
-        "strupr",
-        "system",
-
-        "strlen",
         "strfind",
-        "getpid",
+        "strformat",
+        "strlen",
 
+        /* 24 */
+        "strlwr",
+        "resize",
+        "strtok",
+        "strupr",
+
+        /* 28 */
         "substr",
-        "getenv",
-        "backtick",
+        "system",
+        "trim",
+        "trimleft",
+
+        /* 2c */
+        "trimright",
+        "strchr",
+        "listfind",
+        "listunion"
     };
 
-FILE
-    *infile;
+FILE *infile;
 
-INT8
-    *local_types;
+int8_t *local_types;
 
-size_t
+unsigned
     curoffs,
     nvar;
 
-VAR_
-    *var;
+Variable *var;
 
 void
-    (*procfun[])(void) =
+    (*p_procfun[])(void) =
     {
         fun_jmp,
         fun_jmp_false,
